containertools.split_container_once_by_counts_and_fracture_crossing_spanners
============================================================================

.. autofunction:: abjad.tools.containertools.split_container_once_by_counts_and_fracture_crossing_spanners.split_container_once_by_counts_and_fracture_crossing_spanners
